@@ -105,18 +105,15 @@ public:
     QFont mDefaultMonthViewFont;
     QFont mDefaultAgendaTimeLabelsFont;
 
-    KDateTime::Spec mTimeSpec;
     QStringList mTimeScaleTimeZones;
 
     QSet<EventViews::EventView::ItemIcon> mAgendaViewIcons;
     QSet<EventViews::EventView::ItemIcon> mMonthViewIcons;
 
 protected:
-    void usrSetDefaults() Q_DECL_OVERRIDE;
-    void usrRead() Q_DECL_OVERRIDE;
-    bool usrSave() Q_DECL_OVERRIDE;
-
-    void setTimeZoneDefault();
+    void usrSetDefaults() override;
+    void usrRead() override;
+    bool usrSave() override;
 };
 
 BaseConfig::BaseConfig() : PrefsBase()
@@ -159,8 +156,6 @@ void BaseConfig::usrSetDefaults()
     setAgendaTimeLabelsFont(mDefaultAgendaTimeLabelsFont);
     setMonthViewFont(mDefaultMonthViewFont);
 
-    setTimeZoneDefault();
-
     PrefsBase::usrSetDefaults();
 }
 
@@ -180,10 +175,6 @@ void BaseConfig::usrRead()
         setResourceColor(*it3, color);
     }
 
-    if (!mTimeSpec.isValid()) {
-        setTimeZoneDefault();
-    }
-
 #if 0
     config()->setGroup("FreeBusy");
     if (mRememberRetrievePw) {
@@ -244,19 +235,6 @@ bool BaseConfig::usrSave()
     return KConfigSkeleton::usrSave();
 }
 
-void BaseConfig::setTimeZoneDefault()
-{
-    KTimeZone zone = KSystemTimeZones::local();
-    if (!zone.isValid()) {
-        qCCritical(CALENDARVIEW_LOG) << "KSystemTimeZones::local() return 0";
-        return;
-    }
-
-    qCDebug(CALENDARVIEW_LOG) << "----- time zone:" << zone.name();
-
-    mTimeSpec = zone;
-}
-
 class Q_DECL_HIDDEN Prefs::Private
 {
 public:
@@ -264,8 +242,6 @@ public:
     Private(Prefs *parent, KCoreConfigSkeleton *appConfig)
         : mAppConfig(appConfig), q(parent) {}
 
-    void setTimeZoneDefault();
-
     KConfigSkeletonItem *appConfigItem(const KConfigSkeletonItem *baseConfigItem) const;
 
     void setBool(KCoreConfigSkeleton::ItemBool *baseConfigItem, bool value);
@@ -859,12 +835,7 @@ KDateTime::Spec Prefs::timeSpec() const
 
 QTimeZone Prefs::timeZone() const
 {
-    return QTimeZone(timeSpec().timeZone().name().toUtf8());
-}
-
-void Prefs::setTimeSpec(const KDateTime::Spec &spec)
-{
-    d->mBaseConfig.mTimeSpec = spec;
+    return QTimeZone::systemTimeZone();
 }
 
 bool Prefs::colorAgendaBusyDays() const
